JBoss Tools SVN: r14713 - trunk/ws/docs/reference/en/modules.
by jbosstools-commits@lists.jboss.org
Author: abogachuk
Date: 2009-04-13 13:18:30 -0400 (Mon, 13 Apr 2009)
New Revision: 14713
Modified:
trunk/ws/docs/reference/en/modules/topdown.xml
Log:
https://jira.jboss.org/jira/browse/JBDS-398 - WS guide review, updating the chapters with initial and final sentences
Modified: trunk/ws/docs/reference/en/modules/topdown.xml
===================================================================
--- trunk/ws/docs/reference/en/modules/topdown.xml 2009-04-13 16:57:29 UTC (rev 14712)
+++ trunk/ws/docs/reference/en/modules/topdown.xml 2009-04-13 17:18:30 UTC (rev 14713)
@@ -11,7 +11,7 @@
<title>Creating a Web Service using JBossWS runtime</title>
<para>In this chapter we provide you with the necessary steps to create a Web Service using
- JBossWS runtime.</para>
+ JBossWS runtime. First you need to create a Dynamic Web project:</para>
<section id="createproject">
<title>Creating a Dynamic Web project</title>
@@ -61,7 +61,7 @@
</figure>
</listitem>
</itemizedlist>
- <para>Click on the <property>Finish</property> button.</para>
+ <para>Click on the <property>Finish</property> button. Next you will need to add JBoss Web Service facet to the project:</para>
</section>
<section id="addfacet">
@@ -96,7 +96,7 @@
</imageobject>
</mediaobject>
</figure>
- <para>See how to configure a new JBossWS runtime <link linkend="preference">here</link>:</para>
+ <para>See how to configure a new JBossWS runtime <link linkend="preference">here</link>.</para>
</section>
@@ -107,7 +107,7 @@
WSDL document using JBossWS runtime.</para>
<para>At first, please make sure that you have already created a dynamic Web project with
JBoss Web Service facet installed. </para>
- <para>See how to make it <link linkend="createproject">here</link>> and <link
+ <para>See how to make it <link linkend="createproject">here</link> and <link
linkend="addfacet">here</link>.</para>
<para>To create a Web Service using JBossWS runtime select<emphasis>
15 years, 8 months
JBoss Tools SVN: r14712 - trunk/seam/docs/reference/en/modules.
by jbosstools-commits@lists.jboss.org
Author: chukhutsina
Date: 2009-04-13 12:57:29 -0400 (Mon, 13 Apr 2009)
New Revision: 14712
Modified:
trunk/seam/docs/reference/en/modules/seam_editors.xml
Log:
https://jira.jboss.org/jira/browse/JBDS--680 - view-id are refactored in pages.xml when xhtml/jsp are renamed.The seam doc was corrected according these changes .
Modified: trunk/seam/docs/reference/en/modules/seam_editors.xml
===================================================================
--- trunk/seam/docs/reference/en/modules/seam_editors.xml 2009-04-13 16:54:19 UTC (rev 14711)
+++ trunk/seam/docs/reference/en/modules/seam_editors.xml 2009-04-13 16:57:29 UTC (rev 14712)
@@ -36,7 +36,10 @@
You can edit the pages.xml file in three modes: Graphical, Tree and Source.
</para>
-
+ <para>
+ Seam Pages Editor supports synchronization with Package Explorer.This means that while renaming files in the Package Explorer all the changes immediately affect the pages.xml file.
+
+ </para>
<section>
<title>Graphical Mode</title>
15 years, 8 months
JBoss Tools SVN: r14710 - trunk/seam/plugins/org.jboss.tools.seam.core/src/org/jboss/tools/seam/internal/core/refactoring.
by jbosstools-commits@lists.jboss.org
Author: dazarov
Date: 2009-04-13 11:19:07 -0400 (Mon, 13 Apr 2009)
New Revision: 14710
Modified:
trunk/seam/plugins/org.jboss.tools.seam.core/src/org/jboss/tools/seam/internal/core/refactoring/RenameComponentProcessor.java
Log:
added <component name="<newName>" .../> in components.xml https://jira.jboss.org/jira/browse/JBIDE-1077
Modified: trunk/seam/plugins/org.jboss.tools.seam.core/src/org/jboss/tools/seam/internal/core/refactoring/RenameComponentProcessor.java
===================================================================
--- trunk/seam/plugins/org.jboss.tools.seam.core/src/org/jboss/tools/seam/internal/core/refactoring/RenameComponentProcessor.java 2009-04-13 14:36:33 UTC (rev 14709)
+++ trunk/seam/plugins/org.jboss.tools.seam.core/src/org/jboss/tools/seam/internal/core/refactoring/RenameComponentProcessor.java 2009-04-13 15:19:07 UTC (rev 14710)
@@ -81,6 +81,9 @@
private static final String XHTML_EXT = "xhtml";
private static final String JSP_EXT = "jsp";
private static final String PROPERTIES_EXT = "properties";
+ private static final String COMPONENTS_FILE = "components.xml";
+ private static final String COMPONENT_NODE = "component";
+ private static final String NAME_NODE = "name";
private IFile file;
private ISeamComponent component;
@@ -238,6 +241,8 @@
IDOMModel domModel = (IDOMModel) model;
IDOMDocument document = domModel.getDocument();
scanChildNodes(file, document);
+ if(file.getName().equals(COMPONENTS_FILE))
+ scanChildComponent(file, document);
}
} catch (CoreException e) {
SeamCorePlugin.getDefault().logError(e);
@@ -249,6 +254,31 @@
}
}
}
+
+ private void scanChildComponent(IFile file, Node parent) {
+ NodeList children = parent.getChildNodes();
+ for(int i=0; i<children.getLength(); i++) {
+ Node curentValidatedNode = children.item(i);
+ if(Node.ELEMENT_NODE == curentValidatedNode.getNodeType() && curentValidatedNode.getNodeName().equals(COMPONENT_NODE)) {
+ scanComponentNode(file, curentValidatedNode);
+ }
+ scanChildComponent(file, curentValidatedNode);
+ }
+ }
+
+ private void scanComponentNode(IFile file, Node node) {
+ Node nameNode = node.getAttributes().getNamedItem("name");
+ if(nameNode != null){
+ if(nameNode.getNodeValue().equals(component.getName())){
+ IStructuredDocumentRegion region = ((IDOMNode)node).getFirstStructuredDocumentRegion();
+ checkLastChange(file);
+
+ TextEdit edit = new ReplaceEdit(region.getStartOffset(), region.getLength(), region.getFullText().replace(component.getName(), newName));
+ lastChange.addEdit(edit);
+ }
+ }
+
+ }
private void scanChildNodes(IFile file, Node parent) {
NodeList children = parent.getChildNodes();
@@ -278,6 +308,15 @@
}
TextFileChange lastChange = null;
+
+ private void checkLastChange(IFile file){
+ if(lastChange == null || lastChange.getFile() != file){
+ lastChange = new TextFileChange(file.getName(), file);
+ MultiTextEdit root = new MultiTextEdit();
+ lastChange.setEdit(root);
+ changes.add(lastChange);
+ }
+ }
private void scanString(IFile file, String string, int offset) {
int startEl = string.indexOf("#{"); //$NON-NLS-1$
@@ -288,12 +327,7 @@
for(ELInvocationExpression ie : instance.getExpression().getInvocations()){
ELPropertyInvocation pi = findComponentReference(ie);
if(pi != null){
- if(lastChange == null || lastChange.getFile() != file){
- lastChange = new TextFileChange(file.getName(), file);
- MultiTextEdit root = new MultiTextEdit();
- lastChange.setEdit(root);
- changes.add(lastChange);
- }
+ checkLastChange(file);
TextEdit edit = new ReplaceEdit(offset+pi.getStartPosition(), pi.getName().getStart()+pi.getName().getLength()-pi.getStartPosition(), newName);
lastChange.addEdit(edit);
}
15 years, 8 months
JBoss Tools SVN: r14709 - in trunk/vpe/tests/org.jboss.tools.vpe.ui.test: src/org/jboss/tools/vpe/ui/test and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: mareshkau
Date: 2009-04-13 10:36:33 -0400 (Mon, 13 Apr 2009)
New Revision: 14709
Modified:
trunk/vpe/tests/org.jboss.tools.vpe.ui.test/META-INF/MANIFEST.MF
trunk/vpe/tests/org.jboss.tools.vpe.ui.test/src/org/jboss/tools/vpe/ui/test/ComponentContentTest.java
Log:
Fixing compilation errors in VPE junit when open on eclipse 3.5M6
Modified: trunk/vpe/tests/org.jboss.tools.vpe.ui.test/META-INF/MANIFEST.MF
===================================================================
--- trunk/vpe/tests/org.jboss.tools.vpe.ui.test/META-INF/MANIFEST.MF 2009-04-13 13:19:28 UTC (rev 14708)
+++ trunk/vpe/tests/org.jboss.tools.vpe.ui.test/META-INF/MANIFEST.MF 2009-04-13 14:36:33 UTC (rev 14709)
@@ -20,7 +20,8 @@
org.eclipse.wst.server.core,
org.eclipse.jface.text,
org.jboss.tools.common.model.ui;bundle-version="2.0.0",
- org.jboss.tools.tests;bundle-version="2.0.0";visibility:=reexport
+ org.jboss.tools.tests;bundle-version="2.0.0";visibility:=reexport,
+ org.jboss.tools.common.resref.core;bundle-version="1.0.0"
Bundle-ActivationPolicy: lazy
Bundle-ClassPath: vpe-ui-test.jar
Export-Package: org.jboss.tools.vpe.ui.test,
Modified: trunk/vpe/tests/org.jboss.tools.vpe.ui.test/src/org/jboss/tools/vpe/ui/test/ComponentContentTest.java
===================================================================
--- trunk/vpe/tests/org.jboss.tools.vpe.ui.test/src/org/jboss/tools/vpe/ui/test/ComponentContentTest.java 2009-04-13 13:19:28 UTC (rev 14708)
+++ trunk/vpe/tests/org.jboss.tools.vpe.ui.test/src/org/jboss/tools/vpe/ui/test/ComponentContentTest.java 2009-04-13 14:36:33 UTC (rev 14709)
@@ -19,10 +19,8 @@
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.part.FileEditorInput;
import org.jboss.tools.jst.jsp.jspeditor.JSPMultiPageEditor;
-import org.jboss.tools.vpe.VpeDebug;
import org.jboss.tools.vpe.editor.VpeController;
import org.jboss.tools.vpe.editor.mapping.VpeNodeMapping;
-import org.jboss.tools.vpe.xulrunner.browser.util.DOMTreeDumper;
import org.mozilla.interfaces.nsIDOMElement;
import org.mozilla.interfaces.nsIDOMNode;
import org.w3c.dom.Document;
15 years, 8 months
JBoss Tools SVN: r14708 - trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla.
by jbosstools-commits@lists.jboss.org
Author: dmaliarevich
Date: 2009-04-13 09:19:28 -0400 (Mon, 13 Apr 2009)
New Revision: 14708
Modified:
trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaEditor.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-4062, scroll bars for vpe composite were added.
Modified: trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaEditor.java
===================================================================
--- trunk/hibernatetools/plugins/org.hibernate.eclipse.mapper/plugin.xml 2009-04-13 08:50:03 UTC (rev 14704)
+++ trunk/hibernatetools/plugins/org.hibernate.eclipse.mapper/plugin.xml 2009-04-13 09:55:29 UTC (rev 14705)
@@ -32,10 +32,9 @@
<content-type
base-type="org.eclipse.core.runtime.xml"
file-extensions="xml"
- file-names="hibernate.reveng.xml"
id="revengxmlsource"
name="Hibernate Reverse Engineering Override Content-type"
- priority="normal">
+ priority="high">
<describer class="org.eclipse.core.runtime.content.XMLRootElementContentDescriber">
<parameter
name="element"
15 years, 8 months
JBoss Tools SVN: r14704 - trunk/as/plugins/org.jboss.ide.eclipse.as.core/jbosscore/org/jboss/ide/eclipse/as/core/util.
by jbosstools-commits@lists.jboss.org
Author: rob.stryker(a)jboss.com
Date: 2009-04-13 04:50:03 -0400 (Mon, 13 Apr 2009)
New Revision: 14704
Modified:
trunk/as/plugins/org.jboss.ide.eclipse.as.core/jbosscore/org/jboss/ide/eclipse/as/core/util/ArgsUtil.java
Log:
JBIDE-4026 - found a bug in ArgsUtil while investigating. setArg didn't work if the arg wasn't present yet. Weird.
Modified: trunk/as/plugins/org.jboss.ide.eclipse.as.core/jbosscore/org/jboss/ide/eclipse/as/core/util/ArgsUtil.java
===================================================================
--- trunk/as/plugins/org.jboss.ide.eclipse.as.core/jbosscore/org/jboss/ide/eclipse/as/core/util/ArgsUtil.java 2009-04-13 08:45:19 UTC (rev 14703)
+++ trunk/as/plugins/org.jboss.ide.eclipse.as.core/jbosscore/org/jboss/ide/eclipse/as/core/util/ArgsUtil.java 2009-04-13 08:50:03 UTC (rev 14704)
@@ -118,21 +118,26 @@
public static String setArg(String allArgs, String shortOpt, String longOpt, String value, boolean addQuotes ) {
if( addQuotes )
value = "\"" + value + "\"";
+ boolean found = false;
String[] args = parse(allArgs);
String retVal = "";
for( int i = 0; i < args.length; i++ ) {
if( args[i].equals(shortOpt)) {
args[i+1] = value;
retVal += args[i] + " " + args[++i] + " ";
+ found = true;
} else if( longOpt != null && args[i].startsWith(longOpt + "=")) {
args[i] = longOpt + "=" + value;
retVal += args[i] + " ";
+ found = true;
} else {
retVal += args[i] + " ";
}
}
// turn this to a retval;
+ if( !found )
+ retVal = retVal + longOpt + "=" + value;
return retVal;
}
15 years, 8 months
--- trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaEditor.java 2009-04-13 10:17:23 UTC (rev 14707)
+++ trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaEditor.java 2009-04-13 13:19:28 UTC (rev 14708)
@@ -22,6 +22,7 @@
import org.eclipse.swt.browser.ProgressEvent;
import org.eclipse.swt.browser.ProgressListener;
import org.eclipse.swt.custom.BusyIndicator;
+import org.eclipse.swt.custom.ScrolledComposite;
import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.events.MouseEvent;
@@ -29,6 +30,8 @@
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Color;
+import org.eclipse.swt.graphics.Point;
+import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
@@ -142,27 +145,38 @@
*/
@Override
public void createPartControl(final Composite parent) {
+
+ //Setting Layout for the parent Composite
+ parent.setLayout(new FillLayout());
- //Setting Layout for the parent Composite
- GridLayout layout = new GridLayout(2,false);
+ /*
+ * https://jira.jboss.org/jira/browse/JBIDE-4062
+ * Creating scrollable eclipse element.
+ */
+ ScrolledComposite sc = new ScrolledComposite(parent, SWT.H_SCROLL | SWT.V_SCROLL | SWT.BORDER);
+ sc.setLayout(new FillLayout());
+ Composite composite = new Composite(sc, SWT.NATIVE);
+
+ GridLayout layout = new GridLayout(2,false);
layout.marginHeight = 0;
layout.marginWidth = 2;
layout.verticalSpacing = 2;
layout.horizontalSpacing = 2;
layout.marginBottom = 0;
- parent.setLayout(layout);
-
+ composite.setLayout(layout);
+ composite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
+
// Composite for the left Vertical toolbar
- Composite cmpVerticalToolbar = new Composite(parent, SWT.NONE);
+ Composite cmpVerticalToolbar = new Composite(composite, SWT.NONE);
layout = new GridLayout(1,false);
layout.marginHeight = 2;
layout.marginWidth = 0;
layout.verticalSpacing = 0;
cmpVerticalToolbar.setLayout(layout);
- cmpVerticalToolbar.setLayoutData(new GridData(GridData.FILL_VERTICAL));
+ cmpVerticalToolbar.setLayoutData(new GridData(SWT.LEFT, SWT.TOP, false, false, 1, 1));
// Editors and Toolbar composite
- Composite cmpEdTl = new Composite(parent, SWT.NONE);
+ Composite cmpEdTl = new Composite(composite, SWT.NONE);
GridLayout layoutEdTl = new GridLayout(1, false);
layoutEdTl.verticalSpacing = 0;
layoutEdTl.marginHeight = 0;
@@ -335,6 +349,7 @@
// Display.getCurrent().sleep();
// }
xulRunnerEditor.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
+
}
catch (XulRunnerException e) {
VpePlugin.getPluginLog().logError(e);
@@ -381,7 +396,17 @@
link.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
Label fill = new Label(cmpEd, SWT.WRAP);
fill.setLayoutData(new GridData(GridData.FILL_BOTH));
- }
+ }
+
+ /*
+ * https://jira.jboss.org/jira/browse/JBIDE-4062
+ * Computing elements sizes to set up scroll bars.
+ */
+ Point totalSize = composite.computeSize(SWT.DEFAULT, SWT.DEFAULT);
+ sc.setContent(composite);
+ sc.setExpandHorizontal(true);
+ sc.setExpandVertical(true);
+ sc.setMinSize(totalSize);
}
private ToolItem createToolItem(ToolBar parent, int type, String image,
15 years, 8 months
JBoss Tools SVN: r14707 - workspace/grid/esb-example.
by jbosstools-commits@lists.jboss.org
Author: dennyxu
Date: 2009-04-13 06:17:23 -0400 (Mon, 13 Apr 2009)
New Revision: 14707
Modified:
workspace/grid/esb-example/transform_CSV2XML.zip
workspace/grid/esb-example/transform_CSV2XML_client.zip
workspace/grid/esb-example/transform_XML2POJO.zip
workspace/grid/esb-example/transform_XML2POJO_client.zip
workspace/grid/esb-example/transform_XML2XML_date_manipulation.zip
workspace/grid/esb-example/transform_XML2XML_date_manipulation_client.zip
workspace/grid/esb-example/transform_XML2XML_simple.zip
workspace/grid/esb-example/transform_XML2XML_simple_client.zip
workspace/grid/esb-example/webservice_consumer1.zip
workspace/grid/esb-example/webservice_consumer1_client.zip
workspace/grid/esb-example/webservice_producer.zip
workspace/grid/esb-example/webservice_producer_client.zip
Log:
change defualt project target server runtime to "jboss-soa-p.4.3.0 Runtime"
Modified: workspace/grid/esb-example/transform_CSV2XML.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/transform_CSV2XML_client.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/transform_XML2POJO.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/transform_XML2POJO_client.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/transform_XML2XML_date_manipulation.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/transform_XML2XML_date_manipulation_client.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/transform_XML2XML_simple.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/transform_XML2XML_simple_client.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/webservice_consumer1.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/webservice_consumer1_client.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/webservice_producer.zip
===================================================================
(Binary files differ)
Modified: workspace/grid/esb-example/webservice_producer_client.zip
===================================================================
(Binary files differ)
15 years, 8 months
JBoss Tools SVN: r14706 - workspace/Denny/esb-example.
by jbosstools-commits@lists.jboss.org
Author: dennyxu
Date: 2009-04-13 06:07:40 -0400 (Mon, 13 Apr 2009)
New Revision: 14706
Modified:
workspace/Denny/esb-example/helloworld.zip
workspace/Denny/esb-example/helloworld_action.zip
workspace/Denny/esb-example/helloworld_action_client.zip
workspace/Denny/esb-example/helloworld_file_action.zip
workspace/Denny/esb-example/helloworld_file_action_client.zip
workspace/Denny/esb-example/helloworld_testclient.zip
Log:
change defualt project target server runtime to "jboss-soa-p.4.3.0 Runtime"
Modified: workspace/Denny/esb-example/helloworld.zip
===================================================================
(Binary files differ)
Modified: workspace/Denny/esb-example/helloworld_action.zip
===================================================================
(Binary files differ)
Modified: workspace/Denny/esb-example/helloworld_action_client.zip
===================================================================
(Binary files differ)
Modified: workspace/Denny/esb-example/helloworld_file_action.zip
===================================================================
(Binary files differ)
Modified: workspace/Denny/esb-example/helloworld_file_action_client.zip
===================================================================
(Binary files differ)
Modified: workspace/Denny/esb-example/helloworld_testclient.zip
===================================================================
(Binary files differ)
15 years, 8 months
JBoss Tools SVN: r14705 - trunk/hibernatetools/plugins/org.hibernate.eclipse.mapper.
by jbosstools-commits@lists.jboss.org
Author: dgeraskov
Date: 2009-04-13 05:55:29 -0400 (Mon, 13 Apr 2009)
New Revision: 14705
Modified:
trunk/hibernatetools/plugins/org.hibernate.eclipse.mapper/plugin.xml
Log:
https://jira.jboss.org/jira/browse/JBIDE-4073
Modified: trunk/hibernatetools/plugins/org.hibernate.eclipse.mapper/plugin.xml
===================================================================